#
# spec file for package glu
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           glu
%define lname	libGLU1
Version:        9.0.3
Release:        2.1
Summary:        OpenGL utility library
License:        SGI-B-2.0
Group:          Development/Libraries/C and C++
URL:            http://cgit.freedesktop.org/mesa/glu/

#Git-Clone:	git://anongit.freedesktop.org/mesa/glu
#Git-Web:	http://cgit.freedesktop.org/mesa/glu/
Source:         https://mesa.freedesktop.org/archive/glu/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gl)

%description
GLU offers simple interfaces for building mipmaps; checking for the
presence of extensions in the OpenGL (or other libraries which follow
the same conventions for advertising extensions); drawing
piecewise-linear curves, NURBS, quadrics and other primitives
(including, but not limited to, teapots); tesselating surfaces;
setting up projection matrices and unprojecting screen coordinates to
world coordinates.

%package -n %lname
Summary:        OpenGL utility library
# O/P since 12.3. This Obsoletes is special (since glu is in fact Mesa),
# and should not be copy-pasted without review.
Group:          System/Libraries
Obsoletes:      Mesa-libGLU1 < %version-%release
Provides:       Mesa-libGLU1 = %version-%release

%description -n %lname
GLU offers simple interfaces for building mipmaps; checking for the
presence of extensions in the OpenGL (or other libraries which follow
the same conventions for advertising extensions); drawing
piecewise-linear curves, NURBS, quadrics and other primitives
(including, but not limited to, teapots); tesselating surfaces;
setting up projection matrices and unprojecting screen coordinates to
world coordinates.

This package provides the SGI implementation of GLU previously shipped
with Mesa, but meanwhile developed separately.

%package devel
Summary:        Development files for the GLU API
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       pkgconfig(gl)
# O/P since 12.3
Obsoletes:      Mesa-libGLU-devel < %version-%release
Provides:       Mesa-libGLU-devel = %version-%release

%description devel
GLU offers simple interfaces for building mipmaps; checking for the
presence of extensions in the OpenGL (or other libraries which follow
the same conventions for advertising extensions); drawing
piecewise-linear curves, NURBS, quadrics and other primitives
(including, but not limited to, teapots); tesselating surfaces;
setting up projection matrices and unprojecting screen coordinates to
world coordinates.

This package contains includes headers and static libraries for
compiling programs with GLU.

%prep
%setup -q

%build
%meson -Ddefault_library=shared
%meson_build

%install
%meson_install

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libGLU.so.*

%files devel
%defattr(-,root,root)
%_includedir/GL
%_libdir/libGLU.so
%_libdir/pkgconfig/glu.pc

%changelog
* Fri Aug  4 2023 Stefan Dirsch <sndirsch@suse.com>
- devel package: added missing dep to Mesa GL devel package
  (boo#1213976)
* Mon Jul 24 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 9.0.3
  * drop autotools
  * apple: Fix compatibility version and current version of meson
    build to be compatible with autotools build
  * pkgconfig: Depend on opengl when built with libglvnd
  * pkgconfig: Drop unneeded lines from autotools build
  * pkgconfig: meson build should match autotools requires
  * Remove deprecated register in C++17
- switch to meson build
* Sun Jan  8 2023 Gordon Leung <pirateclip@protonmail.com>
- amend SUSE-SGI-FreeB-2.0 to SPDX's SGI-B-2.0
* Fri Jun 25 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 9.0.2
  * bugfix release
- supersedes u_autoconf-Don-t-modify-CFLAGS-in-configure-scripts.patch
* Wed Jul 24 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 9.0.1
  * libutils/mipmap.c: Fixed possible memory leak
  * pkgconfig: Include -I path for glu itself
  * Remove all uses of the register keyword.
  * Add -D(N)DEBUG to CFLAGS dependent on --enable-debug
  * libutil: Include stddef.h for NULL
  * glu: initialize PriorityQ::order field to NULL in pqNewPriorityQ()
- supersedes U_Add-D-N-DEBUG-to-CFLAGS-dependent-on-enable-debug.patch
* Mon May 29 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #315643-315645, 319159-319161, 319618 (bsc#1041327)
* Tue Jul 12 2016 eich@suse.com
- U_Add-D-N-DEBUG-to-CFLAGS-dependent-on-enable-debug.patch
  u_autoconf-Don-t-modify-CFLAGS-in-configure-scripts.patch
  Avoid debug messages being printed out at runtime (bsc#988411).
* Mon Oct 27 2014 sndirsch@suse.com
- fixed buildrequires: pkgconfig(dri) -> pkgconfig(gl)
- added baselibs.conf as source to specfile
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Sat Oct 20 2012 jengelh@inai.de
- Add Obsoletes/Provides for Mesa-libGLU1
- Avoid running configure twice
* Fri Sep 21 2012 sndirsch@suse.com
- fixed and simplified BuildRequires
* Tue Sep 18 2012 cfarrell@suse.com
- license update: SUSE-SGI-FreeB-2.0
  SGI-FreeB-2.0 is MIT with an advertising clause at the bottom
* Tue Sep 18 2012 coolo@suse.com
- rename to glu and use "official" git snapshot
* Mon Sep  3 2012 sndirsch@suse.com
- created package (since GLU has been split out from Mesa)
